<?xml version="1.0"?> 
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	xmlns:fo="http://www.w3.org/1999/XSL/Format">

<xsl:template match="doc">

<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
<fo:layout-master-set>
	<fo:simple-page-master master-name="A4"
		page-height="297mm" 
		page-width="210mm"
		margin-top="10mm" 
		margin-bottom="5mm"   
		margin-left="12mm" 
		margin-right="12mm">
  		<fo:region-body margin-top="0mm"/>
      	<fo:region-before extent="0mm"/>
      	<fo:region-after extent="10mm"/>
    </fo:simple-page-master>
</fo:layout-master-set>

<fo:page-sequence master-name="A4">
	<fo:static-content flow-name="xsl-region-before">
		<xsl:apply-templates select="header"/>
    </fo:static-content> 
    
    <fo:static-content flow-name="xsl-region-after">
		<xsl:apply-templates select="footer"/>
		<xsl:apply-templates select="page-number"/>
	</fo:static-content>

	<fo:flow flow-name="xsl-region-body">
		<xsl:apply-templates select="docbody"/>
    </fo:flow>
</fo:page-sequence>
</fo:root>
</xsl:template>

<!--************************************************************************************************************-->
<!-- Document Konstanten-Definitionen -->
<!--************************************************************************************************************-->

<xsl:variable name="FONT_SIZE">9pt</xsl:variable>
<xsl:variable name="FONT_SIZE_SMALL">8pt</xsl:variable>
<xsl:variable name="FONT_FAMILY">sans-serif</xsl:variable>
<xsl:variable name="LINE_HEIGHT">10pt</xsl:variable>
<xsl:variable name="LINE_HEIGHT_SMALL">8pt</xsl:variable>
<xsl:variable name="INLINE_FONT_SIZE">8pt</xsl:variable>

<xsl:variable name="BORDER_WIDTH">0.5pt</xsl:variable>
<xsl:variable name="BORDER_SPACING">30pt</xsl:variable>
<xsl:variable name="PADDING">1pt</xsl:variable>
<xsl:variable name="PADDING_TOP">5pt</xsl:variable>

<xsl:variable name="BACKGROUND_COLOR">#E4E4E4</xsl:variable>
<xsl:variable name="BACKGROUND_TITLE">#CCCCCC</xsl:variable>

<!--************************************************************************************************************-->
<!-- Document Body -->
<!--************************************************************************************************************-->

<xsl:template match="docbody">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="header">
	<fo:block font-size="8pt">
	<xsl:apply-templates/>
	</fo:block>
</xsl:template>

<xsl:template match="footer">
	<fo:block font-size="8pt">
		<xsl:apply-templates/>
		<fo:block text-align="center">
		<xsl:text>Page: </xsl:text><fo:page-number/>
		</fo:block>
	</fo:block>
</xsl:template>

<xsl:template match="page-number">
	<fo:block font-size="8pt" text-align="end">
	</fo:block>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="img">
<xsl:choose>
<xsl:when test="@width">
	<fo:external-graphic src="{@src}" width="{@width}" height="{@height}">
	<xsl:apply-templates/>
	</fo:external-graphic>
</xsl:when>
<xsl:otherwise>
	<fo:external-graphic src="{@src}">
	<xsl:apply-templates/>
	</fo:external-graphic>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="br">
	<fo:block>
	<xsl:apply-templates/>
	</fo:block>
</xsl:template>

<xsl:template match="p">
	<fo:block><xsl:text>&#xa0;</xsl:text>
	<xsl:apply-templates/>
	</fo:block>
</xsl:template>
	
<xsl:template match="pagebreak">
 	<fo:block break-before="page">
	<xsl:apply-templates/>
	</fo:block>
 </xsl:template>

<!--************************************************************************************************************-->
<!-- Document Font-->
<!--************************************************************************************************************-->

<xsl:template match="text">
<xsl:choose>
<xsl:when test="@font-size">
	<fo:block font-size="font-size" 
		font-family="{$FONT_FAMILY}"
		line-height="{$LINE_HEIGHT}"
		padding-top="{$PADDING_TOP}">
		<xsl:apply-templates/>
	</fo:block>
</xsl:when>
<xsl:otherwise>
	<fo:block font-size="{$FONT_SIZE}" 
		font-family="{$FONT_FAMILY}"
		line-height="{$LINE_HEIGHT}"
		padding-top="{$PADDING_TOP}">
		<xsl:apply-templates/>
	</fo:block>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="b">
 	<fo:inline font-weight="bold">
	<xsl:apply-templates/>
	</fo:inline>
 </xsl:template>
 
 <xsl:template match="i">
 	<fo:inline font-style="italic">
	<xsl:apply-templates/>
	</fo:inline>
 </xsl:template>
 
 <xsl:template match="big">
 	<fo:inline font-size="14pt" font-weight="bold">
	<xsl:apply-templates/>
	</fo:inline>
</xsl:template>
 
 <xsl:template match="div">
 	<xsl:choose>
 	<xsl:when test="@align='end'">
 		<fo:block text-align="end">
			<xsl:apply-templates/>
		</fo:block>
 	</xsl:when>
 	<xsl:when test="@align='center'">
 		<fo:block text-align="center">
			<xsl:apply-templates/>
		</fo:block>
 	</xsl:when>
 	<xsl:otherwise>
 		<fo:block text-align="start">
			<xsl:apply-templates/>
		</fo:block>
 	</xsl:otherwise>
 	</xsl:choose>
 </xsl:template>
 
 <xsl:template match="small">
 	<fo:inline font-size="{$FONT_SIZE_SMALL}">
	<xsl:apply-templates/>
	</fo:inline>
</xsl:template>

<xsl:template match="h1">
	<fo:block font-size="22pt" 
		font-family="{$FONT_FAMILY}"
		font-weight="bold" 
		line-height="27pt"
		space-after.optimum="15pt"
		text-align="end"
		padding-top="2pt">
		<xsl:apply-templates/>
	</fo:block>
</xsl:template>

<xsl:template match="h2">
	<fo:block font-size="14pt" 
		font-family="{$FONT_FAMILY}"
		font-weight="bold"
		line-height="16pt"
		text-align="start">
        <xsl:apply-templates/>
	</fo:block>
</xsl:template>

<xsl:template match="h3">
	<fo:block font-size="10pt" 
		font-family="{$FONT_FAMILY}"
		font-weight="bold"
		line-height="15pt"
		space-before.optimum="10pt"
		space-after.optimum="10pt"
		background-color="{$BACKGROUND_TITLE}"
		text-align="start"
		padding-top="3pt">
		<xsl:value-of select="cell"/>
        <xsl:apply-templates/>
	</fo:block>
</xsl:template>

<xsl:template match="h4">
	<fo:block font-size="14pt" 
		font-family="{$FONT_FAMILY}"
		font-weight="bold"
		line-height="16pt"
		text-align="end">
        <xsl:apply-templates/>
	</fo:block>
</xsl:template>

<!--************************************************************************************************************-->
<!-- Document Table-->
<!--************************************************************************************************************-->

<xsl:template match="table-body">
	<fo:table-body> <xsl:value-of select="table-body"/>
      	<xsl:for-each select="row"> 
        	<fo:table-row>
        		<xsl:value-of select="row"/><xsl:apply-templates/>
        	</fo:table-row>
        </xsl:for-each>
	</fo:table-body>
</xsl:template>

<xsl:template match="table">
	<fo:table>
		<xsl:for-each select="column"> 
		<fo:table-column column-width="{@width}">
		</fo:table-column>
		</xsl:for-each>
		<xsl:apply-templates/>
	</fo:table>
</xsl:template>

<xsl:template match="cell">
	<xsl:choose>
	<!-- table mit background -->
	<xsl:when test="@bgcolor">
		<fo:table-cell padding="{$PADDING}" background-color="{$BACKGROUND_COLOR}"
			border-top-width="{@north}" border-right-width="{@east}" border-bottom-width="{@south}" border-left-width="{@west}">
			<fo:block font-size="{$FONT_SIZE}" font-family="{$FONT_FAMILY}" line-height="{$LINE_HEIGHT}">
				<xsl:apply-templates/>
			</fo:block>
		</fo:table-cell>
	</xsl:when>
	<!-- table ohne background -->
	<xsl:otherwise>
		<fo:table-cell padding="{$PADDING}" background-color="#FFFFFF"
		border-top-width="{@north}" border-right-width="{@east}" border-bottom-width="{@south}" border-left-width="{@west}">
			<fo:block font-size="{$FONT_SIZE}" font-family="{$FONT_FAMILY}" line-height="{$LINE_HEIGHT}">
				<xsl:apply-templates/>
			</fo:block>
		</fo:table-cell>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>